@@ -15,7 +15,7 @@ from .display_primitives import UUID_str, Color, DashPattern, LineWidth, ArrowTi
 class ChartEdgeStyle:
     def __init__(self, 
         action : str = "",
-        color : Color = Color.BLACK,
+        color : Union[Color, str] = "black",
         dash_pattern : DashPattern = [],
         line_width : float = 2,
         start_tip : Optional[ArrowTip] = None,
@@ -61,7 +61,7 @@ class ChartEdgeStyle:
 
     @color.setter
     def color(self, v : Color):
-        self._color = self._sseq.get_color(v)
+        self._color = v
 
     @property
     def dash_pattern(self) -> DashPattern:
@@ -240,13 +240,16 @@ class ChartStructline(ChartEdge):
     def __init__(self, source_uuid : UUID_str, target_uuid : UUID_str):
         super().__init__(source_uuid, target_uuid)
         self.action = ""
-        self.color = (0, 0, 0, 1)
+        self.color = "black"
         self.dash_pattern = []
         self.line_width = 2
         self.bend = 0
         self.start_tip = None
         self.end_tip = None
         self.visible = True
+    
+    def _normalize_attributes(self):
+        self.color._callback()
 
     def set_style(self, style : Union[str, ChartEdgeStyle], page : Union[int, Tuple[int, int]] = None ) -> "ChartStructline":
         """ Sets the display style of the structline. 
@@ -425,7 +428,7 @@ class SinglePageChartEdge(ChartEdge):
     def __init__(self, source_uuid : UUID_str, target_uuid : UUID_str):
         super().__init__(source_uuid, target_uuid)
         self._action = ""
-        self._color : Color = (0, 0, 0, 1)
+        self._color : Color = "black"
         self._dash_pattern = []
         self._line_width = 3
         self._bend = 0
@@ -433,6 +436,9 @@ class SinglePageChartEdge(ChartEdge):
         self._end_tip = None
         self._visible = True
 
+    def _normalize_attributes(self):
+        self.color = self.color
+
     def set_style(self, style : ChartEdgeStyle) -> "SinglePageChartEdge":
         """ Sets the display style of the edge. 
             
@@ -519,7 +525,10 @@ class SinglePageChartEdge(ChartEdge):
 
     @color.setter
     def color(self, v : Color):
-        self._color = self._sseq.get_color(v)
+        if self._sseq:
+            self._color = self._sseq.get_color(v)
+        else:
+            self._color = v
         self._needs_update()
 
     @property
